# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-08-18 22:25
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_pos', '0020_auto_20170818_2224'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pos',
            name='keyb',
            field=models.CharField(max_length=32, unique=True, verbose_name='Key Broadcast'),
        ),
    ]
