# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-29 20:10
from __future__ import unicode_literals

from django.db import migrations
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_pos', '0015_auto_20170728_1515'),
    ]

    operations = [
        migrations.AddField(
            model_name='poshardware',
            name='value',
            field=jsonfield.fields.JSONField(blank=True, null=True, verbose_name='config'),
        ),
    ]
