# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-08-07 10:20
from __future__ import unicode_literals

import codenerix.models_people
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_pos', '0018_poslog'),
    ]

    operations = [
        migrations.CreateModel(
            name='POSOperator',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('enable', models.BooleanField(default=True, verbose_name='Enable')),
                ('pos', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='pos_operators', to='codenerix_pos.POS', verbose_name='POS')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
            bases=(codenerix.models_people.GenRole, models.Model),
        ),
    ]
