# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-30 11:24
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import jsonfield.fields
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_pos', '0017_pos_channel'),
    ]

    operations = [
        migrations.CreateModel(
            name='POSLog',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('uuid', models.UUIDField(default=uuid.uuid4, editable=False)),
                ('log', jsonfield.fields.JSONField(blank=True, null=True, verbose_name='LOG')),
                ('pos', models.ForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='logs', to='codenerix_pos.POS', verbose_name='POS')),
                ('poshw', models.ForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='logs', to='codenerix_pos.POSHardware', verbose_name='POS')),
            ],
            options={
                'abstract': False,
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
            },
        ),
    ]
