# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-07-19 14:54
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_pos', '0004_auto_20170719_1451'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pos',
            name='hardware',
            field=models.ManyToManyField(blank=True, null=True, related_name='poss', to='codenerix_pos.POSHardware', verbose_name='Hardware'),
        ),
        migrations.AlterField(
            model_name='pos',
            name='payments',
            field=models.ManyToManyField(blank=True, null=True, related_name='poss', to='codenerix_payments.PaymentRequest', verbose_name='Payments'),
        ),
    ]
